
class HardCoded:
    """Constants used throughout the application.

    All hard coded settings/data that are not actual/official configuration options for Flask, Celery, or their
    extensions goes here.
    """
    ADMINS = ['adam.schubert@sg1-game.net']
    ENVIRONMENT = property(lambda self: self.__class__.__name__)


class Config(HardCoded):
    """Default Flask configuration inherited by all environments. Use this for development environments."""
    DEBUG = True
    TESTING = False
    SECRET_KEY = "i_don't_want_my_cookies_expiring_while_developing_token_api"  # nosec: B105
    PORT = 2123
    HOST = '127.0.0.1'
    PKCS11_LIBRARY = '/usr/lib/libIDPrimePKCS11.so'


class Testing(Config):
    TESTING = True


class Production(Config):
    PKCS11_LIBRARY = None  # type: ignore
    DEBUG = False
    SECRET_KEY = None  # type: ignore
    PORT = None  # type: ignore
    HOST = None  # type: ignore
