from typing import Union, Tuple
import flask
import pkcs11
from token_api import __version__
from token_api.blueprints import info
from token_api.extensions import flask_pkcs11

__author__ = "Adam Schubert"


@info.route('/', methods=['GET'])
def get_slots() -> Tuple[Union[flask.Response, str], int]:
    """

    :return:
    """

    template_string = """
    <h1>Token API {{version}}</h1>
    <h2>Detected slots with token present</h2>
<style>
    .table-bordered {
        border: 1px solid #dee2e6;
    }

    .table {
        width: 100%;
        max-width: 100%;
        margin-bottom: 1rem;
        background-color: transparent;
    }

    .table-bordered td, .table-bordered th {
        border: 1px solid #dee2e6;
    }

    table {
        border-collapse: collapse;
    }
</style>
<table class="table table-bordered">
    <tr>
        <th>ID</th>
        <th>Description</th>
        <th>Manufacturer</th>
        <th>Hardware version</th>
        <th>Firmware version</th>
    </tr>

    {% for slot in slots %}
    <tr>
        <td>{{slot.slot_id}}</td>
        <td>{{slot.slot_description}}</td>
        <td>{{slot.manufacturer_id}}</td>
        <td>{{slot.hardware_version}}</td>
        <td>{{slot.firmware_version}}</td>
    </tr>
    {% endfor %}
</table>
    """
    try:
        slots = flask_pkcs11.get_slots(token_present=True)
        return flask.render_template_string(template_string, slots=slots, version=__version__), 200
    except pkcs11.exceptions.PKCS11Error as e:
        return flask.jsonify({'message': 'PKCS11 Error: {}'.format(e)}), 500
